@@ -1,24 +1,22 @@
 /* Search algorithm.
-   Copyright (C) 1989-1998, 2000, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1989-1998, 2000, 2002, 2009 Free Software Foundation, Inc.
    Written by Douglas C. Schmidt <schmidt@ics.uci.edu>
    and Bruno Haible <bruno@clisp.org>.
 
    This file is part of GNU GPERF.
 
-   GNU GPERF is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
-   GNU GPERF is distributed in the hope that it will be useful,
+   This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.
-   If not, write to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* Specification. */
 #include "search.h"
@@ -66,7 +64,7 @@
    where Pos is a set of byte positions,
    each alpha_inc[i] is a nonnegative integer,
    each asso_values[c] is a nonnegative integer,
-   len (keyword) is the keyword's length if !option[NOLENGTH], or 0 otherwise.
+   len (keyword) is the keyword's length if _hash_includes_len, or 0 otherwise.
 
    Theorem 1: If all keywords are different, there is a set Pos such that
    all tuples (keyword[i] : i in Pos) are different.
@@ -105,7 +103,7 @@
      Map (A --> B) := Hom_Set (A, B) is the set of maps from A to B, and
      S(Pos) is the symmetric group over Pos.
 
-   This was the theory for option[NOLENGTH]; if !option[NOLENGTH], slight
+   This was the theory for !_hash_includes_len; if _hash_includes_len, slight
    modifications apply:
      proj1 : String --> Map (Pos --> N) x N
      proj2 : Map (Pos --> N) x N --> Map (Pos --> N) / S(Pos) x N
@@ -177,6 +175,9 @@ Search::prepare ()
               exit (1);
             }
       }
+
+  /* Determine whether the hash function shall include the length.  */
+  _hash_includes_len = !(option[NOLENGTH] || (_min_key_len == _max_key_len));
 }
 
 /* ====================== Finding good byte positions ====================== */
@@ -240,7 +241,7 @@ Search::count_duplicates_tuple (const Positions& positions, const unsigned int *
 
   unsigned int count = 0;
   {
-    Hash_Table representatives (_total_keys, option[NOLENGTH]);
+    Hash_Table representatives (_total_keys, !_hash_includes_len);
     for (KeywordExt_List *temp = _head; temp; temp = temp->rest())
       {
         KeywordExt *keyword = temp->first();
@@ -592,7 +593,7 @@ Search::count_duplicates_multiset (const unsigned int *alpha_inc) const
 
   unsigned int count = 0;
   {
-    Hash_Table representatives (_total_keys, option[NOLENGTH]);
+    Hash_Table representatives (_total_keys, !_hash_includes_len);
     for (KeywordExt_List *temp = _head; temp; temp = temp->rest())
       {
         KeywordExt *keyword = temp->first();
@@ -738,7 +739,7 @@ Search::prepare_asso_values ()
   _max_selchars_length = _key_positions.iterator(_max_key_len).remaining();
 
   /* Check for duplicates, i.e. keywords with the same _selchars array
-     (and - if !option[NOLENGTH] - also the same length).
+     (and - if _hash_includes_len - also the same length).
      We deal with these by building an equivalence class, so that only
      1 keyword is representative of the entire collection.  Only this
      representative remains in the keyword list; the others are accessible
@@ -749,7 +750,7 @@ Search::prepare_asso_values ()
     _list_len = _total_keys;
     _total_duplicates = 0;
     /* Make hash table for efficiency.  */
-    Hash_Table representatives (_list_len, option[NOLENGTH]);
+    Hash_Table representatives (_list_len, !_hash_includes_len);
 
     KeywordExt_List *prev = NULL; /* list node before temp */
     for (temp = _head; temp; )
@@ -849,7 +850,7 @@ Search::prepare_asso_values ()
 
   /* Given the bound for _asso_values[c], we have a bound for the possible
      hash values, as computed in compute_hash().  */
-  _max_hash_value = (option[NOLENGTH] ? 0 : _max_key_len)
+  _max_hash_value = (_hash_includes_len ? _max_key_len : 0)
                     + (_asso_value_max - 1) * _max_selchars_length;
   /* Allocate a sparse bit vector for detection of collisions of hash
      values.  */
@@ -1309,7 +1310,7 @@ Search::find_asso_values ()
                      the yet undetermined asso_values[].  */
                   int hashcode;
                   {
-                    int sum = option[NOLENGTH] ? 0 : keyword->_allchars_length;
+                    int sum = _hash_includes_len ? keyword->_allchars_length : 0;
                     const unsigned int *p = keyword->_selchars;
                     int i = keyword->_selchars_length;
                     for (; i > 0; p++, i--)
@@ -1409,7 +1410,7 @@ Search::find_asso_values ()
                           _asso_value_max = step->_asso_value_max;
                           /* Reinitialize _max_hash_value.  */
                           _max_hash_value =
-                            (option[NOLENGTH] ? 0 : _max_key_len)
+                            (_hash_includes_len ? _max_key_len : 0)
                             + (_asso_value_max - 1) * _max_selchars_length;
                           /* Reinitialize _collision_detector.  */
                           delete _collision_detector;
@@ -1472,7 +1473,7 @@ Search::find_asso_values ()
 inline int
 Search::compute_hash (KeywordExt *keyword) const
 {
-  int sum = option[NOLENGTH] ? 0 : keyword->_allchars_length;
+  int sum = _hash_includes_len ? keyword->_allchars_length : 0;
 
   const unsigned int *p = keyword->_selchars;
   int i = keyword->_selchars_length;
