@@ -20,6 +20,12 @@
 # define SET_BINARY(f) (void)0
 #endif
 
+#if defined __STDC__ || defined __cplusplus
+extern struct language * in_word_set (const char *, int);
+#else
+extern struct language * in_word_set ();
+#endif
+
 #define MAX_LEN 80
 
 int
@@ -49,10 +55,17 @@ main (argc, argv)
       if (buflen == 0)
         break;
 
-      if (in_word_set (buf, buflen) && verbose)
-        printf ("in word set:");
-      else if (verbose)
-        printf ("NOT in word set:");
+      if (in_word_set (buf, buflen))
+        {
+          if (verbose)
+            printf ("in word set:");
+        }
+      else
+        {
+          if (verbose)
+            printf ("NOT in word set:");
+        }
+
       for (p = buf; p < buf + buflen; p += 2)
         printf (" %02X%02X", (unsigned char) p[0], (unsigned char) p[1]);
       printf("\n");
